@@ -330,20 +330,22 @@ def edit_config(model_selected, input_config_dir, output_config_dir, num_steps,
 def train(ckpt_dir='', config_dir='', train_steps=1000, use_tpu=False, checkpoint_every_n=100,
           record_summaries=True):
 
-    if config.endswith('.config'):
-        if not os.path.isfile(config):
-            raise FileNotFoundError('No config file found at {}'.format(config)) 
+    if config_dir.endswith('.config'):
+        if not os.path.isfile(config_dir):
+            raise FileNotFoundError('No config file found at {}'.format(config_dir))
+        else:
+            config = config_dir
     else:
-        if os.path.isdir(config):
-            files = os.listdir(config)
+        if os.path.isdir(config_dir):
+            files = os.listdir(config_dir)
             file_found = False
             for f in files:
                 if not file_found:
                     if f.endswith('.config'):
-                        config = os.path.join(config,f)
+                        config = os.path.join(config_dir,f)
                         file_found = True 
     if not file_found:
-        raise FileNotFoundError('No config file found in this directory {}'.format(config))
+        raise FileNotFoundError('No config file found in this directory {}'.format(config_dir))
 
     tf.config.set_soft_device_placement(True)
     strategy = tf.compat.v2.distribute.MirroredStrategy()
@@ -639,4 +641,7 @@ def infer(path, exported_model_dir, label_map_path, results_dir, disp=True, num_
             counter+=1
             continue
     if counter>0:
-        print(f"{counter} weren't infered")
\ No newline at end of file
+        print(f"{counter} weren't infered")
+
+def run():
+    pass
\ No newline at end of file
